From 1aff06c6a5f49f86a8eb7db571c02d2335e8f966 Mon Sep 17 00:00:00 2001
From: David Malcolm <dmalcolm@redhat.com>
Date: Tue, 15 May 2018 15:01:07 -0400
Subject: [PATCH 50/83] Rename REMARK to NOTE, to distinguish it from
 diagnostic remarks

---
 gcc/optinfo.cc             |   6 +-
 gcc/optinfo.h              |   8 +--
 gcc/profile.c              |   4 +-
 gcc/tree-vect-data-refs.c  |  92 +++++++++++++-------------
 gcc/tree-vect-loop-manip.c |  12 ++--
 gcc/tree-vect-loop.c       | 156 ++++++++++++++++++++++-----------------------
 gcc/tree-vect-slp.c        |  46 ++++++-------
 gcc/tree-vect-stmts.c      |   6 +-
 gcc/tree-vectorizer.h      |   4 +-
 9 files changed, 167 insertions(+), 167 deletions(-)

diff --git a/gcc/optinfo.cc b/gcc/optinfo.cc
index be2e48b..cc77be8 100644
--- a/gcc/optinfo.cc
+++ b/gcc/optinfo.cc
@@ -89,8 +89,8 @@ optinfo_kind_to_string (enum optinfo_kind kind)
       return "success";
     case OPTINFO_KIND_FAILURE:
       return "failure";
-    case OPTINFO_KIND_REMARK:
-      return "remark";
+    case OPTINFO_KIND_NOTE:
+      return "note";
     case OPTINFO_KIND_SCOPE:
       return "scope";
     }
@@ -216,7 +216,7 @@ optinfo::emit_via_fopt_info () const
     case OPTINFO_KIND_FAILURE:
       flags = MSG_MISSED_OPTIMIZATION;
       break;
-    case OPTINFO_KIND_REMARK:
+    case OPTINFO_KIND_NOTE:
     case OPTINFO_KIND_SCOPE:
       flags = MSG_NOTE;
       break;
diff --git a/gcc/profile.c b/gcc/profile.c
index 725b6ca..e6e7b40 100644
--- a/gcc/profile.c
+++ b/gcc/profile.c
@@ -1356,12 +1356,12 @@ branch_prob (void)
       for (gsi = gsi_start_bb (bb); !gsi_end_p (gsi); gsi_next (&gsi))
 	{
 	  gimple *stmt = gsi_stmt (gsi);
-	  OPTINFO (OPTINFO_KIND_REMARK, stmt)
+	  OPTINFO (OPTINFO_KIND_NOTE, stmt)
 	    << "test remark";
 #if 0
 	  remark (gimple_location (stmt), 0, "test remark; execution count=%li",
 		  stmt->bb->count.to_gcov_type ());
-	  maybe_record_optimization (OPTINFO_KIND_REMARK, stmt, "test remark");
+	  maybe_record_optimization (OPTINFO_KIND_NOTE, stmt, "test remark");
 #endif
 #if 0
   /* Expected number of executions: calculated in profile.c.  */
diff --git a/gcc/tree-vect-data-refs.c b/gcc/tree-vect-data-refs.c
index 40ea93d..f9b4b23 100644
--- a/gcc/tree-vect-data-refs.c
+++ b/gcc/tree-vect-data-refs.c
@@ -91,7 +91,7 @@ vect_lanes_optab_supported_p (const char *name, convert_optab optab,
     }
 
   if (optinfo_enabled_p ())
-    OPTINFO_VECT_REMARK
+    OPTINFO_VECT_NOTE
       << optinfo_printf ("can use %s<%s><%s>", name,
 			 GET_MODE_NAME (array_mode),
 			 GET_MODE_NAME (mode));
@@ -184,7 +184,7 @@ vect_check_nonzero_value (loop_vec_info loop_vinfo, tree value)
 
   if (optinfo_enabled_p ())
     {
-      OPTINFO_VECT_REMARK
+      OPTINFO_VECT_NOTE
 	<< "need run-time check that "
 	<< slim (value)
 	<< " is nonzero";
@@ -419,14 +419,14 @@ vect_analyze_data_ref_dependence (struct data_dependence_relation *ddr,
       int dist = dist_v[loop_depth];
 
       if (optinfo_enabled_p ())
-	OPTINFO_VECT_REMARK
+	OPTINFO_VECT_NOTE
 	  << optinfo_printf ("dependence distance  = %d", dist);
 
       if (dist == 0)
 	{
 	  if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK
+	      OPTINFO_VECT_NOTE
 		<< "dependence distance == 0 between "
 		<< slim (DR_REF (dra))
 		<< " and "
@@ -500,7 +500,7 @@ vect_analyze_data_ref_dependence (struct data_dependence_relation *ddr,
 	     vectorization factor.  */
 	  *max_vf = abs (dist);
 	  if (optinfo_enabled_p ())
-	    OPTINFO_VECT_REMARK
+	    OPTINFO_VECT_NOTE
 	      << optinfo_printf ("adjusting maximal vectorization factor to %i",
 				 *max_vf);
 	}
@@ -510,7 +510,7 @@ vect_analyze_data_ref_dependence (struct data_dependence_relation *ddr,
 	  /* Dependence distance does not create dependence, as far as
 	     vectorization is concerned, in this case.  */
 	  if (optinfo_enabled_p ())
-	    OPTINFO_VECT_REMARK
+	    OPTINFO_VECT_NOTE
 	      << optinfo_printf ("dependence distance >= VF");
 	  continue;
 	}
@@ -618,7 +618,7 @@ vect_slp_analyze_data_ref_dependence (struct data_dependence_relation *ddr)
     }
   else if (optinfo_enabled_p ())
     {
-      OPTINFO_VECT_REMARK
+      OPTINFO_VECT_NOTE
 	<< "determined dependence between "
 	<< slim (DR_REF (dra))
 	<< " and "
@@ -770,7 +770,7 @@ vect_record_base_alignment (vec_info *vinfo, gimple *stmt,
       entry = drb;
       if (optinfo_enabled_p ())
 	{
-	  OPTINFO_VECT_REMARK
+	  OPTINFO_VECT_NOTE
 	    << "recording new base alignment for "
 	    << slim (drb->base_address)
 	    << "\n"
@@ -849,7 +849,7 @@ vect_compute_data_ref_alignment (struct data_reference *dr)
   tree vectype = STMT_VINFO_VECTYPE (stmt_info);
 
   if (optinfo_enabled_p ())
-    OPTINFO_VECT_REMARK
+    OPTINFO_VECT_NOTE
       << "vect_compute_data_ref_alignment:";
 
   if (loop_vinfo)
@@ -886,7 +886,7 @@ vect_compute_data_ref_alignment (struct data_reference *dr)
       if (optinfo_enabled_p ())
 	{
 	  if (step_preserves_misalignment_p)
-	    OPTINFO_VECT_REMARK << optinfo_printf (
+	    OPTINFO_VECT_NOTE << optinfo_printf (
 			     "inner step divides the vector alignment.\n");
 	  else
 	    OPTINFO_VECT_FAILURE << (
@@ -947,7 +947,7 @@ vect_compute_data_ref_alignment (struct data_reference *dr)
 	{
 	  if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK
+	      OPTINFO_VECT_NOTE
 		<< "can't force alignment of ref: "
 		<< slim (ref);
 	    }
@@ -959,7 +959,7 @@ vect_compute_data_ref_alignment (struct data_reference *dr)
 	 the analysis phase, before deciding to vectorize the loop.  */
       if (optinfo_enabled_p ())
         {
-          OPTINFO_VECT_REMARK
+          OPTINFO_VECT_NOTE
 	    << "force alignment of "
 	    << slim (ref);
         }
@@ -1059,7 +1059,7 @@ vect_update_misalignment_for_peel (struct data_reference *dr,
     }
 
   if (optinfo_enabled_p ())
-    OPTINFO_VECT_REMARK
+    OPTINFO_VECT_NOTE
       << "Setting misalignment to unknown (-1)";
   SET_DR_MISALIGNMENT (dr, DR_MISALIGNMENT_UNKNOWN);
 }
@@ -1089,7 +1089,7 @@ verify_data_ref_alignment (data_reference_p dr)
     }
 
   if (supportable_dr_alignment != dr_aligned && optinfo_enabled_p ())
-    OPTINFO_VECT_REMARK << "Vectorizing an unaligned access";
+    OPTINFO_VECT_NOTE << "Vectorizing an unaligned access";
 
   return true;
 }
@@ -1185,7 +1185,7 @@ vector_alignment_reachable_p (struct data_reference *dr)
 		int_cst_value (TYPE_SIZE_UNIT (TREE_TYPE (vectype)));
       if (optinfo_enabled_p ())
 	{
-	  OPTINFO_VECT_REMARK
+	  OPTINFO_VECT_NOTE
 	    << optinfo_printf ("data size =" HOST_WIDE_INT_PRINT_DEC, elmsize)
 	    << optinfo_printf (". misalignment = %d.\n", DR_MISALIGNMENT (dr));
 	}
@@ -1238,7 +1238,7 @@ vect_get_data_access_cost (struct data_reference *dr,
     vect_get_store_cost (dr, ncopies, inside_cost, body_cost_vec);
 
   if (optinfo_enabled_p ())
-    OPTINFO_VECT_REMARK
+    OPTINFO_VECT_NOTE
       << optinfo_printf ("vect_get_data_access_cost: inside_cost = %d, "
 			 "outside_cost = %d.\n", *inside_cost, *outside_cost);
 }
@@ -1987,7 +1987,7 @@ vect_enhance_data_refs_alignment (loop_vec_info loop_vinfo)
 	    npeel /= GROUP_SIZE (stmt_info);
 
           if (optinfo_enabled_p ())
-            OPTINFO_VECT_REMARK << optinfo_printf (
+            OPTINFO_VECT_NOTE << optinfo_printf (
                              "Try peeling by %d\n", npeel);
         }
 
@@ -2022,7 +2022,7 @@ vect_enhance_data_refs_alignment (loop_vec_info loop_vinfo)
                 {
                   do_peeling = false;
                   if (optinfo_enabled_p ())
-                    OPTINFO_VECT_REMARK << optinfo_printf (
+                    OPTINFO_VECT_NOTE << optinfo_printf (
                         "Disable peeling, max peels reached: %d\n", max_peel);
                 }
             }
@@ -2073,9 +2073,9 @@ vect_enhance_data_refs_alignment (loop_vec_info loop_vinfo)
 	  SET_DR_MISALIGNMENT (dr0, 0);
 	  if (optinfo_enabled_p ())
             {
-              OPTINFO_VECT_REMARK << optinfo_printf (
+              OPTINFO_VECT_NOTE << optinfo_printf (
                                "Alignment of access forced using peeling.\n");
-              OPTINFO_VECT_REMARK << optinfo_printf (
+              OPTINFO_VECT_NOTE << optinfo_printf (
                                "Peeling for alignment will be applied.\n");
             }
 
@@ -2197,12 +2197,12 @@ vect_enhance_data_refs_alignment (loop_vec_info loop_vinfo)
           dr = STMT_VINFO_DATA_REF (stmt_info);
 	  SET_DR_MISALIGNMENT (dr, 0);
 	  if (optinfo_enabled_p ())
-            OPTINFO_VECT_REMARK << optinfo_printf (
+            OPTINFO_VECT_NOTE << optinfo_printf (
                              "Alignment of access forced using versioning.\n");
         }
 
       if (optinfo_enabled_p ())
-        OPTINFO_VECT_REMARK << optinfo_printf (
+        OPTINFO_VECT_NOTE << optinfo_printf (
                          "Versioning for alignment will be applied.\n");
 
       /* Peeling and versioning can't be done together at this time.  */
@@ -2266,7 +2266,7 @@ vect_find_same_alignment_drs (struct data_dependence_relation *ddr)
   STMT_VINFO_SAME_ALIGN_REFS (stmtinfo_b).safe_push (dra);
   if (optinfo_enabled_p ())
     {
-      OPTINFO_VECT_REMARK << optinfo_printf (
+      OPTINFO_VECT_NOTE << optinfo_printf (
 		       "accesses have the same alignment: ");
       dump_generic_expr (MSG_NOTE, TDF_SLIM, DR_REF (dra));
       dump_printf (MSG_NOTE,  " and ");
@@ -2417,7 +2417,7 @@ vect_analyze_group_access_1 (struct data_reference *dr)
 	{
 	  if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK
+	      OPTINFO_VECT_NOTE
 		<< "Step "
 		<< slim (step)
 		<< " is not a multiple of the element size for "
@@ -2447,7 +2447,7 @@ vect_analyze_group_access_1 (struct data_reference *dr)
 	  GROUP_GAP (stmt_info) = groupsize - 1;
 	  if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK
+	      OPTINFO_VECT_NOTE
 		<< "Detected single element interleaving "
 		<< slim (DR_REF (dr))
 		<< " step "
@@ -2471,7 +2471,7 @@ vect_analyze_group_access_1 (struct data_reference *dr)
           return true;
         }
 
-      OPTINFO_VECT_REMARK
+      OPTINFO_VECT_NOTE
 	<< "using strided accesses";
       STMT_VINFO_STRIDED_P (stmt_info) = true;
       return true;
@@ -2588,7 +2588,7 @@ vect_analyze_group_access_1 (struct data_reference *dr)
       GROUP_SIZE (vinfo_for_stmt (stmt)) = groupsize;
       if (optinfo_enabled_p ())
 	{
-	  OPTINFO_VECT_REMARK << optinfo_printf (
+	  OPTINFO_VECT_NOTE << optinfo_printf (
 			   "Detected interleaving ");
 	  if (DR_IS_READ (dr))
 	    dump_printf (MSG_NOTE, "load ");
@@ -2598,7 +2598,7 @@ vect_analyze_group_access_1 (struct data_reference *dr)
 		       (unsigned)groupsize);
 	  dump_gimple_stmt (MSG_NOTE, TDF_SLIM, stmt, 0);
 	  if (GROUP_GAP (vinfo_for_stmt (stmt)) != 0)
-	    OPTINFO_VECT_REMARK << optinfo_printf (
+	    OPTINFO_VECT_NOTE << optinfo_printf (
 			     "There is a gap of %u elements after the group\n",
 			     GROUP_GAP (vinfo_for_stmt (stmt)));
 	}
@@ -2683,7 +2683,7 @@ vect_analyze_data_ref_access (struct data_reference *dr)
       if (loop->safelen < 2)
 	{
 	  if (optinfo_enabled_p ())
-	    OPTINFO_VECT_REMARK << optinfo_printf (
+	    OPTINFO_VECT_NOTE << optinfo_printf (
 			     "zero step in inner loop of nest\n");
 	  return false;
 	}
@@ -2700,7 +2700,7 @@ vect_analyze_data_ref_access (struct data_reference *dr)
       if (integer_zerop (step))
 	{
 	  if (optinfo_enabled_p ())
-	    OPTINFO_VECT_REMARK << optinfo_printf (
+	    OPTINFO_VECT_NOTE << optinfo_printf (
 	                     "zero step in outer loop.\n");
 	  return DR_IS_READ (dr);
 	}
@@ -2723,7 +2723,7 @@ vect_analyze_data_ref_access (struct data_reference *dr)
   if (loop && nested_in_vect_loop_p (loop, stmt))
     {
       if (optinfo_enabled_p ())
-	OPTINFO_VECT_REMARK << optinfo_printf (
+	OPTINFO_VECT_NOTE << optinfo_printf (
 	                 "grouped access in outer loop.\n");
       return false;
     }
@@ -2988,7 +2988,7 @@ vect_analyze_data_ref_accesses (vec_info *vinfo)
 
 	  if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK << optinfo_printf (
+	      OPTINFO_VECT_NOTE << optinfo_printf (
 			       "Detected interleaving ");
 	      if (DR_IS_READ (dra))
 		dump_printf (MSG_NOTE, "load ");
@@ -3171,7 +3171,7 @@ dependence_distance_ge_vf (data_dependence_relation *ddr,
 
   if (optinfo_enabled_p ())
     {
-      OPTINFO_VECT_REMARK << optinfo_printf (
+      OPTINFO_VECT_NOTE << optinfo_printf (
 		       "dependence distance between ");
       dump_generic_expr (MSG_NOTE, TDF_SLIM, DR_REF (DDR_A (ddr)));
       dump_printf (MSG_NOTE,  " and ");
@@ -3213,7 +3213,7 @@ vect_check_lower_bound (loop_vec_info loop_vinfo, tree expr, bool unsigned_p,
 	    lower_bounds[i].min_value = min_value;
 	    if (optinfo_enabled_p ())
 	      {
-		OPTINFO_VECT_REMARK << optinfo_printf (
+		OPTINFO_VECT_NOTE << optinfo_printf (
 				 "updating run-time check to ");
 		dump_lower_bound (MSG_NOTE, lower_bounds[i]);
 		dump_printf (MSG_NOTE, "\n");
@@ -3225,7 +3225,7 @@ vect_check_lower_bound (loop_vec_info loop_vinfo, tree expr, bool unsigned_p,
   vec_lower_bound lower_bound (expr, unsigned_p, min_value);
   if (optinfo_enabled_p ())
     {
-      OPTINFO_VECT_REMARK << optinfo_printf ( "need a run-time check that ");
+      OPTINFO_VECT_NOTE << optinfo_printf ( "need a run-time check that ");
       dump_lower_bound (MSG_NOTE, lower_bound);
       dump_printf (MSG_NOTE, "\n");
     }
@@ -3357,7 +3357,7 @@ vect_prune_runtime_alias_test_list (loop_vec_info loop_vinfo)
 	    {
 	      if (optinfo_enabled_p ())
 		{
-		  OPTINFO_VECT_REMARK << optinfo_printf ( "checking that ");
+		  OPTINFO_VECT_NOTE << optinfo_printf ( "checking that ");
 		  dump_generic_expr (MSG_NOTE, TDF_SLIM, new_pair.first);
 		  dump_printf (MSG_NOTE, " and ");
 		  dump_generic_expr (MSG_NOTE, TDF_SLIM, new_pair.second);
@@ -3382,7 +3382,7 @@ vect_prune_runtime_alias_test_list (loop_vec_info loop_vinfo)
 	{
 	  if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK << optinfo_printf (
+	      OPTINFO_VECT_NOTE << optinfo_printf (
 			       "no need for alias check between ");
 	      dump_generic_expr (MSG_NOTE, TDF_SLIM, DR_REF (dr_a));
 	      dump_printf (MSG_NOTE, " and ");
@@ -3405,7 +3405,7 @@ vect_prune_runtime_alias_test_list (loop_vec_info loop_vinfo)
 	  bool unsigned_p = dr_known_forward_stride_p (dr_a);
 	  if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK << optinfo_printf ( "no alias between ");
+	      OPTINFO_VECT_NOTE << optinfo_printf ( "no alias between ");
 	      dump_generic_expr (MSG_NOTE, TDF_SLIM, DR_REF (dr_a));
 	      dump_printf (MSG_NOTE, " and ");
 	      dump_generic_expr (MSG_NOTE, TDF_SLIM, DR_REF (dr_b));
@@ -3481,7 +3481,7 @@ vect_prune_runtime_alias_test_list (loop_vec_info loop_vinfo)
 					     access_size_b);
 	  if (res >= 0 && optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK << optinfo_printf (
+	      OPTINFO_VECT_NOTE << optinfo_printf (
 			       "can tell at compile time that ");
 	      dump_generic_expr (MSG_NOTE, TDF_SLIM, DR_REF (dr_a));
 	      dump_printf (MSG_NOTE, " and ");
@@ -3498,7 +3498,7 @@ vect_prune_runtime_alias_test_list (loop_vec_info loop_vinfo)
 	  if (res == 1)
 	    {
 	      if (optinfo_enabled_p ())
-		OPTINFO_VECT_REMARK << optinfo_printf (
+		OPTINFO_VECT_NOTE << optinfo_printf (
 				 "not vectorized: compilation time alias.\n");
 	      return false;
 	    }
@@ -3520,7 +3520,7 @@ vect_prune_runtime_alias_test_list (loop_vec_info loop_vinfo)
   unsigned int count = (comp_alias_ddrs.length ()
 			+ check_unequal_addrs.length ());
 
-  OPTINFO_VECT_REMARK << optinfo_printf (
+  OPTINFO_VECT_NOTE << optinfo_printf (
 		   "improved number of alias checks from %d to %d\n",
 		   may_alias_ddrs.length (), count);
   if ((int) count > PARAM_VALUE (PARAM_VECT_MAX_VERSION_FOR_ALIAS_CHECKS))
@@ -4174,7 +4174,7 @@ again:
 
 	  if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK
+	      OPTINFO_VECT_NOTE
 		<< "analyze in outer loop: "
 		<< slim (init_ref);
 	    }
@@ -4186,7 +4186,7 @@ again:
 
           if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK << optinfo_printf (
+	      OPTINFO_VECT_NOTE << optinfo_printf (
                                "\touter base_address: ");
 	      dump_generic_expr (MSG_NOTE, TDF_SLIM,
                                  STMT_VINFO_DR_BASE_ADDRESS (stmt_info));
@@ -4293,7 +4293,7 @@ again:
 	{
 	  if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK
+	      OPTINFO_VECT_NOTE
 		<< "got vectype for stmt: "
 		<< stmt
 		<< slim (STMT_VINFO_VECTYPE (stmt_info));
@@ -4571,7 +4571,7 @@ vect_create_addr_base_for_vector_ref (gimple *stmt,
 
   if (optinfo_enabled_p ())
     {
-      OPTINFO_VECT_REMARK << optinfo_printf ( "created ");
+      OPTINFO_VECT_NOTE << optinfo_printf ( "created ");
       dump_generic_expr (MSG_NOTE, TDF_SLIM, addr_base);
       dump_printf (MSG_NOTE, "\n");
     }
@@ -4699,7 +4699,7 @@ vect_create_data_ref_ptr (gimple *stmt, tree aggr_type, struct loop *at_loop,
   if (optinfo_enabled_p ())
     {
       tree dr_base_type = TREE_TYPE (DR_BASE_OBJECT (dr));
-      pending_optinfo po = OPTINFO_VECT_REMARK
+      pending_optinfo po = OPTINFO_VECT_NOTE
 	<< optinfo_printf ("create %s-pointer variable to type: ",
 			   get_tree_code_name (TREE_CODE (aggr_type)))
 	<< slim (aggr_type);
diff --git a/gcc/tree-vect-loop-manip.c b/gcc/tree-vect-loop-manip.c
index 9e86bce..23ab955 100644
--- a/gcc/tree-vect-loop-manip.c
+++ b/gcc/tree-vect-loop-manip.c
@@ -1499,7 +1499,7 @@ vect_update_ivs_after_vectorizer (loop_vec_info loop_vinfo,
       gphi *phi1 = gsi1.phi ();
       if (dump_enabled_p ())
 	{
-	  OPTINFO_VECT_REMARK
+	  OPTINFO_VECT_NOTE
 	    << "vect_update_ivs_after_vectorizer: phi: "
 	    << phi;
 	}
@@ -1508,7 +1508,7 @@ vect_update_ivs_after_vectorizer (loop_vec_info loop_vinfo,
       if (!iv_phi_p (phi))
 	{
 	  if (dump_enabled_p ())
-	    OPTINFO_VECT_REMARK << "reduc or virtual phi. skip.";
+	    OPTINFO_VECT_NOTE << "reduc or virtual phi. skip.";
 	  continue;
 	}
 
@@ -1637,7 +1637,7 @@ vect_gen_prolog_loop_niters (loop_vec_info loop_vinfo,
       int npeel = LOOP_VINFO_PEELING_FOR_ALIGNMENT (loop_vinfo);
 
       if (dump_enabled_p ())
-        OPTINFO_VECT_REMARK
+        OPTINFO_VECT_NOTE
 	  << optinfo_printf ("known peeling = %d", npeel);
 
       iters = build_int_cst (niters_type, npeel);
@@ -1669,7 +1669,7 @@ vect_gen_prolog_loop_niters (loop_vec_info loop_vinfo,
 
   if (dump_enabled_p ())
     {
-      OPTINFO_VECT_REMARK
+      OPTINFO_VECT_NOTE
 	<< "niters for prolog loop: "
 	<< slim (iters);
     }
@@ -1788,7 +1788,7 @@ vect_prepare_for_masked_peels (loop_vec_info loop_vinfo)
 
   if (dump_enabled_p ())
     {
-      OPTINFO_VECT_REMARK << optinfo_printf (
+      OPTINFO_VECT_NOTE << optinfo_printf (
 		       "misalignment for fully-masked loop: ");
       dump_generic_expr (MSG_NOTE, TDF_SLIM, misalign_in_elems);
       dump_printf (MSG_NOTE, "\n");
@@ -2926,7 +2926,7 @@ vect_create_cond_for_alias_checks (loop_vec_info loop_vinfo, tree * cond_expr)
   create_runtime_alias_checks (LOOP_VINFO_LOOP (loop_vinfo),
 			       &comp_alias_ddrs, cond_expr);
   if (dump_enabled_p ())
-    OPTINFO_VECT_REMARK
+    OPTINFO_VECT_NOTE
       << optinfo_printf ("created %u versioning for alias checks",
 			 comp_alias_ddrs.length ());
 }
diff --git a/gcc/tree-vect-loop.c b/gcc/tree-vect-loop.c
index b0cf33c..9e9c847 100644
--- a/gcc/tree-vect-loop.c
+++ b/gcc/tree-vect-loop.c
@@ -228,7 +228,7 @@ vect_determine_vectorization_factor (loop_vec_info loop_vinfo)
 	  phi = si.phi ();
 	  stmt_info = vinfo_for_stmt (phi);
 	  if (optinfo_enabled_p ())
-	    OPTINFO_VECT_REMARK
+	    OPTINFO_VECT_NOTE
 	      << "==> examining phi: "
 	      << phi;
 
@@ -242,7 +242,7 @@ vect_determine_vectorization_factor (loop_vec_info loop_vinfo)
 
 	      if (optinfo_enabled_p ())
 		{
-		  OPTINFO_VECT_REMARK
+		  OPTINFO_VECT_NOTE
 		    << "get vectype for scalar type:  "
 		    << slim (scalar_type);
 		}
@@ -261,14 +261,14 @@ vect_determine_vectorization_factor (loop_vec_info loop_vinfo)
 	      STMT_VINFO_VECTYPE (stmt_info) = vectype;
 
 	      if (optinfo_enabled_p ())
-		OPTINFO_VECT_REMARK
+		OPTINFO_VECT_NOTE
 		  << "vectype: "
 		  << slim (vectype);
 
 	      if (optinfo_enabled_p ())
 		{
 #if 0
-		  OPTINFO_VECT_REMARK
+		  OPTINFO_VECT_NOTE
 		    << "nunits = "
 		    << TYPE_VECTOR_SUBPARTS (vectype);
 #endif
@@ -292,7 +292,7 @@ vect_determine_vectorization_factor (loop_vec_info loop_vinfo)
 
 	  if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK
+	      OPTINFO_VECT_NOTE
 		<< "==> examining statement: "
 		<< stmt;
 	    }
@@ -313,7 +313,7 @@ vect_determine_vectorization_factor (loop_vec_info loop_vinfo)
                   stmt_info = vinfo_for_stmt (pattern_stmt);
                   if (optinfo_enabled_p ())
                     {
-                      OPTINFO_VECT_REMARK
+                      OPTINFO_VECT_NOTE
 			<< "==> examining pattern statement: "
 			<< stmt;
                     }
@@ -321,7 +321,7 @@ vect_determine_vectorization_factor (loop_vec_info loop_vinfo)
               else
 	        {
 	          if (optinfo_enabled_p ())
-	            OPTINFO_VECT_REMARK
+	            OPTINFO_VECT_NOTE
 		      << "skip";
                   gsi_next (&si);
 	          continue;
@@ -363,7 +363,7 @@ vect_determine_vectorization_factor (loop_vec_info loop_vinfo)
 		    {
 		      if (optinfo_enabled_p ())
 			{
-			  OPTINFO_VECT_REMARK
+			  OPTINFO_VECT_NOTE
 			    << "==> examining pattern def stmt: "
 			    << pattern_def_stmt;
 			}
@@ -469,7 +469,7 @@ vect_determine_vectorization_factor (loop_vec_info loop_vinfo)
 
 	      if (optinfo_enabled_p ())
 		{
-		  OPTINFO_VECT_REMARK
+		  OPTINFO_VECT_NOTE
 		    << "get vectype for scalar type:  "
 		    << slim (scalar_type);
 		}
@@ -490,7 +490,7 @@ vect_determine_vectorization_factor (loop_vec_info loop_vinfo)
 
 	      if (optinfo_enabled_p ())
 		{
-		  OPTINFO_VECT_REMARK
+		  OPTINFO_VECT_NOTE
 		    << "vectype: "
 		    << slim (vectype);
 		}
@@ -510,7 +510,7 @@ vect_determine_vectorization_factor (loop_vec_info loop_vinfo)
 							     &dummy);
 	      if (optinfo_enabled_p ())
 		{
-		  OPTINFO_VECT_REMARK
+		  OPTINFO_VECT_NOTE
 		    << "get vectype for scalar type:  "
 		    << slim (scalar_type);
 		}
@@ -544,14 +544,14 @@ vect_determine_vectorization_factor (loop_vec_info loop_vinfo)
 
 	  if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK
+	      OPTINFO_VECT_NOTE
 		<< "vectype: " << slim (vf_vectype);
 	    }
 
 	  if (optinfo_enabled_p ())
 	    {
 #if 0
-	      OPTINFO_VECT_REMARK
+	      OPTINFO_VECT_NOTE
 		<< "nunits = "
 	      dump_dec (MSG_NOTE, TYPE_VECTOR_SUBPARTS (vf_vectype));
 	      dump_printf (MSG_NOTE, "\n");
@@ -572,7 +572,7 @@ vect_determine_vectorization_factor (loop_vec_info loop_vinfo)
   if (optinfo_enabled_p ())
     {
 #if 0
-      OPTINFO_VECT_REMARK
+      OPTINFO_VECT_NOTE
 	<< "vectorization factor = "
       dump_dec (MSG_NOTE, vectorization_factor);
 #endif
@@ -729,7 +729,7 @@ vect_is_simple_iv_evolution (unsigned loop_nb, tree access_fn, tree * init,
 
   if (optinfo_enabled_p ())
     {
-      OPTINFO_VECT_REMARK
+      OPTINFO_VECT_NOTE
 	<< "step: " << slim (step_expr)
 	<< ",  init: " << slim (init_expr);
     }
@@ -786,7 +786,7 @@ vect_analyze_scalar_cycles_1 (loop_vec_info loop_vinfo, struct loop *loop)
 
       if (optinfo_enabled_p ())
 	{
-	  OPTINFO_VECT_REMARK
+	  OPTINFO_VECT_NOTE
 	    << "Analyze phi: " << phi;
 	}
 
@@ -804,7 +804,7 @@ vect_analyze_scalar_cycles_1 (loop_vec_info loop_vinfo, struct loop *loop)
 	  STRIP_NOPS (access_fn);
 	  if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK
+	      OPTINFO_VECT_NOTE
 		<< "Access function of PHI: " << slim (access_fn);
 	    }
 	  STMT_VINFO_LOOP_PHI_EVOLUTION_BASE_UNCHANGED (stmt_vinfo)
@@ -827,7 +827,7 @@ vect_analyze_scalar_cycles_1 (loop_vec_info loop_vinfo, struct loop *loop)
       gcc_assert (STMT_VINFO_LOOP_PHI_EVOLUTION_PART (stmt_vinfo) != NULL_TREE);
 
       if (optinfo_enabled_p ())
-	OPTINFO_VECT_REMARK
+	OPTINFO_VECT_NOTE
 	  << "Detected induction";
       STMT_VINFO_DEF_TYPE (stmt_vinfo) = vect_induction_def;
     }
@@ -843,7 +843,7 @@ vect_analyze_scalar_cycles_1 (loop_vec_info loop_vinfo, struct loop *loop)
 
       if (optinfo_enabled_p ())
         {
-          OPTINFO_VECT_REMARK
+          OPTINFO_VECT_NOTE
 	    << "Analyze phi: " << phi;
         }
 
@@ -857,7 +857,7 @@ vect_analyze_scalar_cycles_1 (loop_vec_info loop_vinfo, struct loop *loop)
           if (double_reduc)
             {
               if (optinfo_enabled_p ())
-                OPTINFO_VECT_REMARK
+                OPTINFO_VECT_NOTE
 		  << "Detected double reduction";
 
               STMT_VINFO_DEF_TYPE (stmt_vinfo) = vect_double_reduction_def;
@@ -869,7 +869,7 @@ vect_analyze_scalar_cycles_1 (loop_vec_info loop_vinfo, struct loop *loop)
               if (loop != LOOP_VINFO_LOOP (loop_vinfo))
                 {
                   if (optinfo_enabled_p ())
-                    OPTINFO_VECT_REMARK
+                    OPTINFO_VECT_NOTE
 		      << "Detected vectorizable nested cycle";
 
                   STMT_VINFO_DEF_TYPE (stmt_vinfo) = vect_nested_cycle;
@@ -879,7 +879,7 @@ vect_analyze_scalar_cycles_1 (loop_vec_info loop_vinfo, struct loop *loop)
               else
                 {
                   if (optinfo_enabled_p ())
-                    OPTINFO_VECT_REMARK
+                    OPTINFO_VECT_NOTE
 		      << "Detected reduction";
 
                   STMT_VINFO_DEF_TYPE (stmt_vinfo) = vect_reduction_def;
@@ -1565,7 +1565,7 @@ vect_analyze_loop_form_1 (struct loop *loop, gcond **loop_cond,
 	}
 
       if (optinfo_enabled_p ())
-        OPTINFO_VECT_REMARK
+        OPTINFO_VECT_NOTE
 	  << "Considering outer-loop vectorization";
     }
 
@@ -1671,7 +1671,7 @@ vect_analyze_loop_form (struct loop *loop)
 
   if (!LOOP_VINFO_NITERS_KNOWN_P (loop_vinfo))
     if (optinfo_enabled_p ())
-      OPTINFO_VECT_REMARK
+      OPTINFO_VECT_NOTE
 	<< "symbolic number of iterations is "
 	<< details (number_of_iterations);
 
@@ -1734,13 +1734,13 @@ vect_update_vf_for_slp (loop_vec_info loop_vinfo)
 
   if (only_slp_in_loop)
     {
-      OPTINFO_VECT_REMARK
+      OPTINFO_VECT_NOTE
 	<< "Loop contains only SLP stmts";
       vectorization_factor = LOOP_VINFO_SLP_UNROLLING_FACTOR (loop_vinfo);
     }
   else
     {
-      OPTINFO_VECT_REMARK
+      OPTINFO_VECT_NOTE
 	<< "Loop contains SLP and non-SLP stmts";
       /* Both the vectorization factor and unroll factor have the form
 	 current_vector_size * X for some rational X, so they must have
@@ -1754,7 +1754,7 @@ vect_update_vf_for_slp (loop_vec_info loop_vinfo)
   if (optinfo_enabled_p ())
     {
 #if 0
-      OPTINFO_VECT_REMARK
+      OPTINFO_VECT_NOTE
 	<< "Updating vectorization factor to ");
       dump_dec (MSG_NOTE, vectorization_factor);
 #endif
@@ -1819,7 +1819,7 @@ vect_analyze_loop_operations (loop_vec_info loop_vinfo)
           stmt_info = vinfo_for_stmt (phi);
           if (optinfo_enabled_p ())
             {
-              OPTINFO_VECT_REMARK
+              OPTINFO_VECT_NOTE
 		<< "examining phi: "
 		<< phi;
             }
@@ -1934,7 +1934,7 @@ vect_analyze_loop_operations (loop_vec_info loop_vinfo)
   if (!need_to_vectorize)
     {
       if (optinfo_enabled_p ())
-        OPTINFO_VECT_REMARK
+        OPTINFO_VECT_NOTE
 	  << "All the computation can be taken out of the loop";
       if (optinfo_enabled_p ())
 	OPTINFO_VECT_FAILURE
@@ -2009,7 +2009,7 @@ vect_analyze_loop_costing (loop_vec_info loop_vinfo)
 	OPTINFO_VECT_FAILURE
 	  << "not vectorized: vectorization not profitable";
       if (optinfo_enabled_p ())
-	OPTINFO_VECT_REMARK
+	OPTINFO_VECT_NOTE
 	  << ("not vectorized: iteration count smaller than user "
 	      "specified loop bound parameter or minimum profitable "
 	      "iterations (whichever is more conservative)");
@@ -2027,7 +2027,7 @@ vect_analyze_loop_costing (loop_vec_info loop_vinfo)
 	OPTINFO_VECT_FAILURE
 	  << "not vectorized: estimated iteration count too small";
       if (optinfo_enabled_p ())
-	OPTINFO_VECT_REMARK
+	OPTINFO_VECT_NOTE
 	  << ("not vectorized: estimated iteration count smaller "
 	      "than specified loop bound parameter or minimum "
 	      "profitable iterations (whichever is more "
@@ -2240,7 +2240,7 @@ start_over:
   if (LOOP_VINFO_NITERS_KNOWN_P (loop_vinfo) && optinfo_enabled_p ())
     {
 #if 0
-      OPTINFO_VECT_REMARK
+      OPTINFO_VECT_NOTE
 	<< "vectorization_factor = "
       dump_dec (MSG_NOTE, vectorization_factor);
       dump_printf (MSG_NOTE, ", niters = " HOST_WIDE_INT_PRINT_DEC "\n",
@@ -2316,10 +2316,10 @@ start_over:
   if (optinfo_enabled_p ())
     {
       if (LOOP_VINFO_FULLY_MASKED_P (loop_vinfo))
-	OPTINFO_VECT_REMARK
+	OPTINFO_VECT_NOTE
 	  << "using a fully-masked loop";
       else
-	OPTINFO_VECT_REMARK
+	OPTINFO_VECT_NOTE
 	  << "not using a fully-masked loop";
     }
 
@@ -2336,7 +2336,7 @@ start_over:
       if (known_lt (wi::to_widest (scalar_niters), vf))
 	{
 	  if (optinfo_enabled_p ())
-	    OPTINFO_VECT_REMARK
+	    OPTINFO_VECT_NOTE
 	      << ("loop has not enough iterations to support"
 		  " peeling for gaps");
 	  return false;
@@ -2388,7 +2388,7 @@ start_over:
       || LOOP_VINFO_PEELING_FOR_NITER (loop_vinfo))
     {
       if (optinfo_enabled_p ())
-        OPTINFO_VECT_REMARK
+        OPTINFO_VECT_NOTE
 	  << "epilog loop required";
       if (!vect_can_advance_ivs_p (loop_vinfo)
 	  || !slpeel_can_duplicate_loop_p (LOOP_VINFO_LOOP (loop_vinfo),
@@ -2483,7 +2483,7 @@ again:
     }
 
   if (optinfo_enabled_p ())
-    OPTINFO_VECT_REMARK
+    OPTINFO_VECT_NOTE
       << "re-trying with SLP disabled";
 
   /* Roll back state appropriately.  No SLP this time.  */
@@ -2567,7 +2567,7 @@ vect_analyze_loop (struct loop *loop, loop_vec_info orig_loop_vinfo)
       && LOOP_VINFO_VECTORIZABLE_P (loop_vec_info_for_loop (loop_outer (loop))))
     {
       if (optinfo_enabled_p ())
-	OPTINFO_VECT_REMARK
+	OPTINFO_VECT_NOTE
 	  << "outer-loop already vectorized";
       return NULL;
     }
@@ -2616,7 +2616,7 @@ vect_analyze_loop (struct loop *loop, loop_vec_info orig_loop_vinfo)
       if (optinfo_enabled_p ())
 	{
 #if 0
-	  OPTINFO_VECT_REMARK
+	  OPTINFO_VECT_NOTE
 	    << "***** Re-trying analysis with vector size ";
 	  dump_dec (MSG_NOTE, current_vector_size);
 	  dump_printf (MSG_NOTE, "\n");
@@ -2919,7 +2919,7 @@ vect_is_slp_reduction (loop_vec_info loop_info, gimple *phi,
   	    {
 	      if (optinfo_enabled_p ())
 		{
-		  OPTINFO_VECT_REMARK
+		  OPTINFO_VECT_NOTE
 		    << "swapping oprnds: " << next_stmt;
 		}
 
@@ -3379,7 +3379,7 @@ vect_is_simple_reduction (loop_vec_info loop_info, gimple *phi,
       if (optinfo_enabled_p ())
         {
 	  pending_optinfo info
-	    = OPTINFO_VECT_REMARK
+	    = OPTINFO_VECT_NOTE
 	        << "reduction: multiple types: operation type: "
 		<< slim (type)
 		<< ", operands types: "
@@ -3594,7 +3594,7 @@ vect_get_known_peeling_cost (loop_vec_info loop_vinfo, int peel_iters_prologue,
     {
       *peel_iters_epilogue = assumed_vf / 2;
       if (optinfo_enabled_p ())
-        OPTINFO_VECT_REMARK
+        OPTINFO_VECT_NOTE
 	  << ("cost model: epilogue peel iters set to vf/2 "
 	      "because loop iterations are unknown");
 
@@ -3679,7 +3679,7 @@ vect_estimate_min_profitable_iters (loop_vec_info loop_vinfo,
   /* Cost model disabled.  */
   if (unlimited_cost_model (LOOP_VINFO_LOOP (loop_vinfo)))
     {
-      OPTINFO_VECT_REMARK
+      OPTINFO_VECT_NOTE
 	<< "cost model disabled";
       *ret_min_profitable_niters = 0;
       *ret_min_profitable_estimate = 0;
@@ -3944,7 +3944,7 @@ vect_estimate_min_profitable_iters (loop_vec_info loop_vinfo,
     {
       /* FIXME: do we want to do something special for such a table of
 	 data?  */
-      OPTINFO_VECT_REMARK
+      OPTINFO_VECT_NOTE
 	<< "Cost model analysis:\n"
 	<< optinfo_printf ("  Vector inside of loop cost: %d\n",
 			   vec_inside_cost)
@@ -4022,7 +4022,7 @@ vect_estimate_min_profitable_iters (loop_vec_info loop_vinfo,
     min_profitable_iters = assumed_vf + peel_iters_prologue;
 
   if (optinfo_enabled_p ())
-    OPTINFO_VECT_REMARK
+    OPTINFO_VECT_NOTE
       << optinfo_printf ("  Runtime profitability threshold = %d",
 			 min_profitable_iters);
 
@@ -4048,7 +4048,7 @@ vect_estimate_min_profitable_iters (loop_vec_info loop_vinfo,
     }
   min_profitable_estimate = MAX (min_profitable_estimate, min_profitable_iters);
   if (optinfo_enabled_p ())
-    OPTINFO_VECT_REMARK
+    OPTINFO_VECT_NOTE
       << optinfo_printf ("  Static estimate profitability threshold = %d",
 			 min_profitable_estimate);
 
@@ -4300,7 +4300,7 @@ vect_model_induction_cost (stmt_vec_info stmt_info, int ncopies)
 				 stmt_info, 0, vect_prologue);
 
   if (optinfo_enabled_p ())
-    OPTINFO_VECT_REMARK
+    OPTINFO_VECT_NOTE
       << optinfo_printf ("vect_model_induction_cost: inside_cost = %d, "
 			 "prologue_cost = %d",
 			 inside_cost, prologue_cost);
@@ -4895,7 +4895,7 @@ vect_create_epilog_for_reduction (vec<tree> vect_defs, gimple *stmt,
 
           if (optinfo_enabled_p ())
             {
-              OPTINFO_VECT_REMARK
+              OPTINFO_VECT_NOTE
 		<< "transform reduction: created def-use cycle: "
 		<< phi << SSA_NAME_DEF_STMT (def);
             }
@@ -5382,7 +5382,7 @@ vect_create_epilog_for_reduction (vec<tree> vect_defs, gimple *stmt,
          v_out2 = reduc_expr <v_out1>  */
 
       if (optinfo_enabled_p ())
-        OPTINFO_VECT_REMARK
+        OPTINFO_VECT_NOTE
 	  << "Reduce using direct vector reduction";
 
       vec_elem_type = TREE_TYPE (TREE_TYPE (new_phi_result));
@@ -5653,7 +5653,7 @@ vect_create_epilog_for_reduction (vec<tree> vect_defs, gimple *stmt,
           tree rhs;
 
           if (optinfo_enabled_p ())
-            OPTINFO_VECT_REMARK
+            OPTINFO_VECT_NOTE
 	      << "Reduce using vector shifts";
 
 	  mode1 = TYPE_MODE (vectype1);
@@ -5682,7 +5682,7 @@ vect_create_epilog_for_reduction (vec<tree> vect_defs, gimple *stmt,
 	     s_out3 = extract_field <v_out2, bitpos>  */
 
 	  if (optinfo_enabled_p ())
-	    OPTINFO_VECT_REMARK
+	    OPTINFO_VECT_NOTE
 	      << "extract scalar result";
 
 	  rhs = build3 (BIT_FIELD_REF, scalar_type, new_temp,
@@ -5706,7 +5706,7 @@ vect_create_epilog_for_reduction (vec<tree> vect_defs, gimple *stmt,
                }  */
 
           if (optinfo_enabled_p ())
-            OPTINFO_VECT_REMARK
+            OPTINFO_VECT_NOTE
 	      << "Reduce using scalar code";
 
 	  int vec_size_in_bits = tree_to_uhwi (TYPE_SIZE (vectype1));
@@ -6030,7 +6030,7 @@ vect_finalize_reduction:
                                loop_latch_edge (outer_loop), UNKNOWN_LOCATION);
                   if (optinfo_enabled_p ())
                     {
-                      OPTINFO_VECT_REMARK
+                      OPTINFO_VECT_NOTE
 			<< "created double reduction phi node: "
 			<< vect_phi;
                     }
@@ -6831,7 +6831,7 @@ vectorizable_reduction (gimple *stmt, gimple_stmt_iterator *gsi,
 	  if (cond_reduc_val)
 	    {
 	      if (optinfo_enabled_p ())
-		OPTINFO_VECT_REMARK
+		OPTINFO_VECT_NOTE
 		  << "condition expression based on integer induction";
 	      STMT_VINFO_VEC_REDUCTION_TYPE (stmt_info)
 		= INTEGER_INDUC_COND_REDUCTION;
@@ -6856,7 +6856,7 @@ vectorizable_reduction (gimple *stmt, gimple_stmt_iterator *gsi,
 	      if (e && (integer_onep (e) || integer_zerop (e)))
 		{
 		  if (optinfo_enabled_p ())
-		    OPTINFO_VECT_REMARK
+		    OPTINFO_VECT_NOTE
 		      << ("condition expression based on "
 			  "compile time constant");
 		  /* Record reduction code at analysis stage.  */
@@ -7228,7 +7228,7 @@ vectorizable_reduction (gimple *stmt, gimple_stmt_iterator *gsi,
       if (! max_loop_iterations (loop, &ni))
 	{
 	  if (optinfo_enabled_p ())
-	    OPTINFO_VECT_REMARK
+	    OPTINFO_VECT_NOTE
 	      << "loop count not known, cannot create cond reduction";
 	  return false;
 	}
@@ -7242,7 +7242,7 @@ vectorizable_reduction (gimple *stmt, gimple_stmt_iterator *gsi,
       if (wi::geu_p (ni, wi::to_widest (max_index)))
 	{
 	  if (optinfo_enabled_p ())
-	    OPTINFO_VECT_REMARK
+	    OPTINFO_VECT_NOTE
 	      << "loop size is greater than data size";
 	  return false;
 	}
@@ -7345,7 +7345,7 @@ vectorizable_reduction (gimple *stmt, gimple_stmt_iterator *gsi,
 	}
       if (optinfo_enabled_p ()
 	  && reduction_type == FOLD_LEFT_REDUCTION)
-	OPTINFO_VECT_REMARK
+	OPTINFO_VECT_NOTE
 	  << "using an in-order (fold-left) reduction";
       STMT_VINFO_TYPE (stmt_info) = reduc_vec_info_type;
       return true;
@@ -7354,7 +7354,7 @@ vectorizable_reduction (gimple *stmt, gimple_stmt_iterator *gsi,
   /* Transform.  */
 
   if (optinfo_enabled_p ())
-    OPTINFO_VECT_REMARK
+    OPTINFO_VECT_NOTE
       << "transform reduction";
 
   /* FORNOW: Multiple types are not supported for condition.  */
@@ -7721,7 +7721,7 @@ vectorizable_induction (gimple *phi,
      [X, X + S, X + 2*S, X + 3*S].  */
 
   if (optinfo_enabled_p ())
-    OPTINFO_VECT_REMARK
+    OPTINFO_VECT_NOTE
       << "transform induction phi";
 
   latch_e = loop_latch_edge (iv_loop);
@@ -8115,7 +8115,7 @@ vectorizable_induction (gimple *phi,
 	  STMT_VINFO_VEC_STMT (stmt_vinfo) = new_stmt;
 	  if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK
+	      OPTINFO_VECT_NOTE
 		<< "vector of inductions after inner-loop:" << new_stmt;
 	    }
 	}
@@ -8124,7 +8124,7 @@ vectorizable_induction (gimple *phi,
 
   if (optinfo_enabled_p ())
     {
-      OPTINFO_VECT_REMARK
+      OPTINFO_VECT_NOTE
 	<< "transform induction: created def-use cycle: "
 	<< induction_phi << SSA_NAME_DEF_STMT (vec_def);
     }
@@ -8172,7 +8172,7 @@ vectorizable_live_operation (gimple *stmt,
     {
       gcc_assert (is_simple_and_all_uses_invariant (stmt, loop_vinfo));
       if (optinfo_enabled_p ())
-	OPTINFO_VECT_REMARK
+	OPTINFO_VECT_NOTE
 	  << "statement is simple and uses invariant.  Leaving in place";
       return true;
     }
@@ -8380,7 +8380,7 @@ vect_loop_kill_debug_uses (struct loop *loop, gimple *stmt)
 	      if (gimple_debug_bind_p (ustmt))
 		{
 		  if (optinfo_enabled_p ())
-		    OPTINFO_VECT_REMARK
+		    OPTINFO_VECT_NOTE
 		      << "killing debug use";
 
 		  gimple_debug_bind_reset_value (ustmt);
@@ -8592,7 +8592,7 @@ vect_transform_loop (loop_vec_info loop_vinfo)
       && !LOOP_VINFO_NITERS_KNOWN_P (loop_vinfo))
     {
       if (optinfo_enabled_p ())
-	OPTINFO_VECT_REMARK
+	OPTINFO_VECT_NOTE
 	  << optinfo_printf ("Profitability threshold is %d loop iterations",
 			     th);
       check_profitability = true;
@@ -8695,7 +8695,7 @@ vect_transform_loop (loop_vec_info loop_vinfo)
 	  gphi *phi = si.phi ();
 	  if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK
+	      OPTINFO_VECT_NOTE
 		<< "------>vectorizing phi: " << phi;
 	    }
 	  stmt_info = vinfo_for_stmt (phi);
@@ -8713,7 +8713,7 @@ vect_transform_loop (loop_vec_info loop_vinfo)
 	      && (maybe_ne
 		  (TYPE_VECTOR_SUBPARTS (STMT_VINFO_VECTYPE (stmt_info)), vf))
 	      && optinfo_enabled_p ())
-	    OPTINFO_VECT_REMARK
+	    OPTINFO_VECT_NOTE
 	      << "multiple-types";
 
 	  if ((STMT_VINFO_DEF_TYPE (stmt_info) == vect_induction_def
@@ -8722,7 +8722,7 @@ vect_transform_loop (loop_vec_info loop_vinfo)
 	      && ! PURE_SLP_STMT (stmt_info))
 	    {
 	      if (optinfo_enabled_p ())
-		OPTINFO_VECT_REMARK
+		OPTINFO_VECT_NOTE
 		  << "transform phi";
 	      vect_transform_stmt (phi, NULL, NULL, NULL, NULL);
 	    }
@@ -8751,7 +8751,7 @@ vect_transform_loop (loop_vec_info loop_vinfo)
 
 	  if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK
+	      OPTINFO_VECT_NOTE
 		<< "------>vectorizing statement: " << stmt;
 	    }
 
@@ -8822,7 +8822,7 @@ vect_transform_loop (loop_vec_info loop_vinfo)
 		    {
 		      if (optinfo_enabled_p ())
 			{
-			  OPTINFO_VECT_REMARK
+			  OPTINFO_VECT_NOTE
 			    << "==> vectorizing pattern def stmt: "
 			    << pattern_def_stmt;
 			}
@@ -8849,7 +8849,7 @@ vect_transform_loop (loop_vec_info loop_vinfo)
 		  && optinfo_enabled_p ())
 		  /* For SLP VF is set according to unrolling factor, and not
 		     to vector size, hence for SLP this print is not valid.  */
-		OPTINFO_VECT_REMARK
+		OPTINFO_VECT_NOTE
 		  << "multiple-types";
 	    }
 
@@ -8880,7 +8880,7 @@ vect_transform_loop (loop_vec_info loop_vinfo)
 
 	  /* -------- vectorize statement ------------ */
 	  if (optinfo_enabled_p ())
-	    OPTINFO_VECT_REMARK
+	    OPTINFO_VECT_NOTE
 	      << "transform statement";
 
 	  grouped_store = false;
@@ -8996,17 +8996,17 @@ vect_transform_loop (loop_vec_info loop_vinfo)
     {
       if (!LOOP_VINFO_EPILOGUE_P (loop_vinfo))
 	{
-	  OPTINFO_VECT_REMARK
+	  OPTINFO_VECT_NOTE
 	    << "LOOP VECTORIZED";
 	  if (loop->inner)
-	    OPTINFO_VECT_REMARK
+	    OPTINFO_VECT_NOTE
 	      << "OUTER LOOP VECTORIZED";
 	  dump_printf (MSG_NOTE, "\n");
 	}
       else
 	{
 #if 0
-	  OPTINFO_VECT_REMARK
+	  OPTINFO_VECT_NOTE
 	    << "LOOP EPILOGUE VECTORIZED (VS="
 	  dump_dec (MSG_NOTE, current_vector_size);
 	    << ")";
@@ -9167,7 +9167,7 @@ optimize_mask_stores (struct loop *loop)
       if (dom_info_available_p (CDI_DOMINATORS))
 	set_immediate_dominator (CDI_DOMINATORS, store_bb, bb);
       if (optinfo_enabled_p ())
-	OPTINFO_VECT_REMARK
+	OPTINFO_VECT_NOTE
 	  << optinfo_printf ("Create new block %d to sink mask stores.",
 			     store_bb->index);
       /* Create vector comparison with boolean result.  */
@@ -9207,7 +9207,7 @@ optimize_mask_stores (struct loop *loop)
 	  gsi_to = gsi_start_bb (store_bb);
 	  if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK
+	      OPTINFO_VECT_NOTE
 		<< "Move stmt to created bb " << last;
 	    }
 	  /* Move all stored value producers if possible.  */
@@ -9273,7 +9273,7 @@ optimize_mask_stores (struct loop *loop)
 
 	      /* Can move STMT1 to STORE_BB.  */
 	      if (optinfo_enabled_p ())
-		OPTINFO_VECT_REMARK
+		OPTINFO_VECT_NOTE
 		  << "move stmt to created bb"
 		  << stmt1;
 	      gsi_move_before (&gsi_from, &gsi_to);
diff --git a/gcc/tree-vect-slp.c b/gcc/tree-vect-slp.c
index 59fc283..5df159d 100644
--- a/gcc/tree-vect-slp.c
+++ b/gcc/tree-vect-slp.c
@@ -551,7 +551,7 @@ again:
 			   gimple_assign_rhs2_ptr (stmt));
       if (optinfo_enabled_p ())
 	{
-	  OPTINFO_VECT_REMARK
+	  OPTINFO_VECT_NOTE
 	    << "swapped operands to match def types in "
 	    << stmt;
 	}
@@ -648,7 +648,7 @@ vect_build_slp_tree_1 (vec_info *vinfo, unsigned char *swap,
 
       if (optinfo_enabled_p ())
 	{
-	  OPTINFO_VECT_REMARK
+	  OPTINFO_VECT_NOTE
 	    << "Build SLP for "
 	    << stmt;
 	}
@@ -1243,7 +1243,7 @@ vect_build_slp_tree_2 (vec_info *vinfo,
 		    vect_free_slp_tree (grandchild);
 		  SLP_TREE_CHILDREN (child).truncate (0);
 
-		  OPTINFO_VECT_REMARK << optinfo_printf (
+		  OPTINFO_VECT_NOTE << optinfo_printf (
 				   "Building parent vector operands from "
 				   "scalars instead\n");
 		  oprnd_info->def_stmts = vNULL;
@@ -1273,7 +1273,7 @@ vect_build_slp_tree_2 (vec_info *vinfo,
 	     scalar version.  */
 	  && !is_pattern_stmt_p (vinfo_for_stmt (stmt)))
 	{
-	  OPTINFO_VECT_REMARK << optinfo_printf (
+	  OPTINFO_VECT_NOTE << optinfo_printf (
 			   "Building vector operands from scalars\n");
 	  child = vect_create_new_slp_node (oprnd_info->def_stmts);
 	  SLP_TREE_DEF_TYPE (child) = vect_external_def;
@@ -1346,7 +1346,7 @@ vect_build_slp_tree_2 (vec_info *vinfo,
 	  while (j != group_size);
 
 	  /* Swap mismatched definition stmts.  */
-	  OPTINFO_VECT_REMARK << optinfo_printf (
+	  OPTINFO_VECT_NOTE << optinfo_printf (
 			   "Re-trying with swapped operands of stmts ");
 	  for (j = 0; j < group_size; ++j)
 	    if (matches[j] == !swap_not_matching)
@@ -1421,7 +1421,7 @@ vect_build_slp_tree_2 (vec_info *vinfo,
 			vect_free_slp_tree (grandchild);
 		      SLP_TREE_CHILDREN (child).truncate (0);
 
-		      OPTINFO_VECT_REMARK << optinfo_printf (
+		      OPTINFO_VECT_NOTE << optinfo_printf (
 				       "Building parent vector operands from "
 				       "scalars instead\n");
 		      oprnd_info->def_stmts = vNULL;
@@ -1641,7 +1641,7 @@ vect_supported_load_permutation_p (slp_instance slp_instn)
 
   if (optinfo_enabled_p ())
     {
-      OPTINFO_VECT_REMARK << optinfo_printf ( "Load permutation ");
+      OPTINFO_VECT_NOTE << optinfo_printf ( "Load permutation ");
       FOR_EACH_VEC_ELT (SLP_INSTANCE_LOADS (slp_instn), i, node)
 	if (node->load_permutation.exists ())
 	  FOR_EACH_VEC_ELT (node->load_permutation, j, next)
@@ -2097,7 +2097,7 @@ vect_split_slp_store_group (gimple *first_stmt, unsigned group1_size)
   GROUP_GAP (first_vinfo) += group2_size;
 
   if (optinfo_enabled_p ())
-    OPTINFO_VECT_REMARK << optinfo_printf ( "Split group into %d and %d\n",
+    OPTINFO_VECT_NOTE << optinfo_printf ( "Split group into %d and %d\n",
 		     group1_size, group2_size);
 
   return group2;
@@ -2329,7 +2329,7 @@ vect_analyze_slp_instance (vec_info *vinfo,
 
       if (optinfo_enabled_p ())
 	{
-	  OPTINFO_VECT_REMARK << optinfo_printf (
+	  OPTINFO_VECT_NOTE << optinfo_printf (
 			   "Final SLP tree for instance:\n");
 	  vect_print_slp_tree (MSG_NOTE, vect_location, node);
 	}
@@ -2470,7 +2470,7 @@ vect_make_slp_decision (loop_vec_info loop_vinfo)
 
   if (decided_to_slp && optinfo_enabled_p ())
     {
-      OPTINFO_VECT_REMARK << optinfo_printf (
+      OPTINFO_VECT_NOTE << optinfo_printf (
 		       "Decided to SLP %d instances. Unrolling factor ",
 		       decided_to_slp);
       dump_dec (MSG_NOTE, unrolling_factor);
@@ -2532,7 +2532,7 @@ vect_detect_hybrid_slp_stmts (slp_tree node, unsigned i, slp_vect_type stype)
 	      {
 		if (optinfo_enabled_p ())
 		  {
-		    OPTINFO_VECT_REMARK << optinfo_printf ( "use of SLP "
+		    OPTINFO_VECT_NOTE << optinfo_printf ( "use of SLP "
 				     "def in non-SLP stmt: ");
 		    dump_gimple_stmt (MSG_NOTE, TDF_SLIM, use_stmt, 0);
 		  }
@@ -2546,7 +2546,7 @@ vect_detect_hybrid_slp_stmts (slp_tree node, unsigned i, slp_vect_type stype)
     {
       if (optinfo_enabled_p ())
 	{
-	  OPTINFO_VECT_REMARK << optinfo_printf ( "marking hybrid: ");
+	  OPTINFO_VECT_NOTE << optinfo_printf ( "marking hybrid: ");
 	  dump_gimple_stmt (MSG_NOTE, TDF_SLIM, stmt, 0);
 	}
       STMT_SLP_TYPE (stmt_vinfo) = hybrid;
@@ -2577,7 +2577,7 @@ vect_detect_hybrid_slp_1 (tree *tp, int *, void *data)
 	{
 	  if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK << optinfo_printf ( "marking hybrid: ");
+	      OPTINFO_VECT_NOTE << optinfo_printf ( "marking hybrid: ");
 	      dump_gimple_stmt (MSG_NOTE, TDF_SLIM, def_stmt, 0);
 	    }
 	  STMT_SLP_TYPE (vinfo_for_stmt (def_stmt)) = hybrid;
@@ -2739,7 +2739,7 @@ vect_slp_analyze_node_operations (vec_info *vinfo, slp_tree node,
       tree scalar_type = TREE_TYPE (gimple_get_lhs (stmt));
       if (optinfo_enabled_p ())
 	{
-	  OPTINFO_VECT_REMARK
+	  OPTINFO_VECT_NOTE
 	    << "get vectype for scalar type:  "
 	    << slim (scalar_type);
 	}
@@ -2758,7 +2758,7 @@ vect_slp_analyze_node_operations (vec_info *vinfo, slp_tree node,
 
       if (optinfo_enabled_p ())
 	{
-	  OPTINFO_VECT_REMARK
+	  OPTINFO_VECT_NOTE
 	    << "vectype:  "
 	    << slim (vectype);
 	}
@@ -2826,7 +2826,7 @@ vect_slp_analyze_operations (vec_info *vinfo)
 					     SLP_INSTANCE_TREE (instance),
 					     instance))
         {
-	  OPTINFO_VECT_REMARK
+	  OPTINFO_VECT_NOTE
 	    << "removing SLP instance operations starting from: "
 	    << SLP_TREE_SCALAR_STMTS (SLP_INSTANCE_TREE (instance))[0];
 	  vect_free_slp_instance (instance);
@@ -2964,7 +2964,7 @@ vect_bb_vectorization_profitable_p (bb_vec_info bb_vinfo)
 
   if (optinfo_enabled_p ())
     {
-      OPTINFO_VECT_REMARK << optinfo_printf ( "Cost model analysis: \n");
+      OPTINFO_VECT_NOTE << optinfo_printf ( "Cost model analysis: \n");
       dump_printf (MSG_NOTE, "  Vector inside of basic block cost: %d\n",
 		   vec_inside_cost);
       dump_printf (MSG_NOTE, "  Vector prologue cost: %d\n", vec_prologue_cost);
@@ -3097,7 +3097,7 @@ vect_slp_analyze_bb_1 (gimple_stmt_iterator region_begin,
       if (! vect_slp_analyze_and_verify_instance_alignment (instance)
 	  || ! vect_slp_analyze_instance_dependence (instance))
 	{
-	  OPTINFO_VECT_REMARK << optinfo_printf (
+	  OPTINFO_VECT_NOTE << optinfo_printf (
 			   "removing SLP instance operations starting from: ");
 	  dump_gimple_stmt (MSG_NOTE, TDF_SLIM,
 			    SLP_TREE_SCALAR_STMTS
@@ -3144,7 +3144,7 @@ vect_slp_analyze_bb_1 (gimple_stmt_iterator region_begin,
     }
 
   if (optinfo_enabled_p ())
-    OPTINFO_VECT_REMARK << optinfo_printf (
+    OPTINFO_VECT_NOTE << optinfo_printf (
 		     "Basic block will be vectorized using SLP\n");
 
   return bb_vinfo;
@@ -3215,13 +3215,13 @@ vect_slp_bb (basic_block bb)
 	  && dbg_cnt (vect_slp))
 	{
 	  if (optinfo_enabled_p ())
-	    OPTINFO_VECT_REMARK
+	    OPTINFO_VECT_NOTE
 	      << "SLPing BB part";
 
 	  vect_schedule_slp (bb_vinfo);
 
 	  if (optinfo_enabled_p ())
-	    OPTINFO_VECT_REMARK
+	    OPTINFO_VECT_NOTE
 	      << "basic block part vectorized";
 
 	  vectorized = true;
@@ -3260,7 +3260,7 @@ vect_slp_bb (basic_block bb)
 	  current_vector_size = vector_sizes[next_size++];
 	  if (optinfo_enabled_p ())
 	    {
-	      OPTINFO_VECT_REMARK
+	      OPTINFO_VECT_NOTE
 		<< "***** Re-trying analysis with vector size ";
 	      // FIXME:
 	      dump_dec (MSG_NOTE, current_vector_size);
@@ -4226,7 +4226,7 @@ vect_schedule_slp (vec_info *vinfo)
       is_store = vect_schedule_slp_instance (SLP_INSTANCE_TREE (instance),
                                              instance, bst_map);
       if (optinfo_enabled_p ())
-	OPTINFO_VECT_REMARK 
+	OPTINFO_VECT_NOTE
 	  << "vectorizing stmts using SLP";
     }
   delete bst_map;
diff --git a/gcc/tree-vect-stmts.c b/gcc/tree-vect-stmts.c
index b6c7d27..23662b8 100644
--- a/gcc/tree-vect-stmts.c
+++ b/gcc/tree-vect-stmts.c
@@ -9883,7 +9883,7 @@ vect_is_simple_use (tree operand, vec_info *vinfo,
 
   if (optinfo_enabled_p ())
     {
-      OPTINFO_VECT_REMARK
+      OPTINFO_VECT_NOTE
 	<< "vect_is_simple_use: operand "
 	<< slim (operand);
     }
@@ -9917,7 +9917,7 @@ vect_is_simple_use (tree operand, vec_info *vinfo,
   *def_stmt = SSA_NAME_DEF_STMT (operand);
   if (optinfo_enabled_p ())
     {
-      OPTINFO_VECT_REMARK
+      OPTINFO_VECT_NOTE
 	<< "def_stmt: " << *def_stmt;
     }
 
@@ -9931,7 +9931,7 @@ vect_is_simple_use (tree operand, vec_info *vinfo,
 
   if (optinfo_enabled_p ())
     {
-      pending_optinfo po = OPTINFO_VECT_REMARK << "type of def: ";
+      pending_optinfo po = OPTINFO_VECT_NOTE << "type of def: ";
       switch (*dt)
 	{
 	case vect_uninitialized_def:
diff --git a/gcc/tree-vectorizer.h b/gcc/tree-vectorizer.h
index 4b7e946..c0db732 100644
--- a/gcc/tree-vectorizer.h
+++ b/gcc/tree-vectorizer.h
@@ -1405,8 +1405,8 @@ emit_optinfo_at_vect_location (const location &impl_location,
 
 /* Emit a remark relating to an optimization at the vect location.  */
 
-#define OPTINFO_VECT_REMARK \
-  (emit_optinfo_at_vect_location (OPTINFO_IMPL_LOCATION, OPTINFO_KIND_REMARK))
+#define OPTINFO_VECT_NOTE \
+  (emit_optinfo_at_vect_location (OPTINFO_IMPL_LOCATION, OPTINFO_KIND_NOTE))
 
 /* FIXME.  */
 
diff --git a/gcc/optinfo.h b/gcc/optinfo.h
index 8bc3fa9..9489516 100644
--- a/gcc/optinfo.h
+++ b/gcc/optinfo.h
@@ -207,7 +207,7 @@ enum optinfo_kind
 {
   OPTINFO_KIND_SUCCESS,
   OPTINFO_KIND_FAILURE,
-  OPTINFO_KIND_REMARK,
+  OPTINFO_KIND_NOTE,
   OPTINFO_KIND_SCOPE
 };
 
@@ -307,10 +307,10 @@ class pending_optinfo
 #define OPTINFO_SUCCESS(LOC)\
   OPTINFO(OPTINFO_KIND_SUCCESS, (LOC))
 
 /* Emit a remark relating to an optimization at LOC.  */
 
-#define OPTINFO_REMARK(LOC)\
-  OPTINFO(OPTINFO_KIND_REMARK, (LOC))
+#define OPTINFO_NOTE(LOC)\
+  OPTINFO(OPTINFO_KIND_NOTE, (LOC))
 
 extern void push_optinfo_scope ();
 extern void pop_optinfo_scope ();
@@ -307,10 +307,10 @@ class pending_optinfo
   OPTINFO(OPTINFO_KIND_SUCCESS, (LOC))
 
-/* Emit a remark relating to an optimization at LOC.  */
+/* Emit a note relating to an optimization at LOC.  */
 
-- 
1.8.5.3

